/*
 * ------------------------------------------------------------------------
 *
 *  Copyright (C) 2003 - 2013
 *  University of Konstanz, Germany and
 *  KNIME GmbH, Konstanz, Germany
 *  Website: http://www.knime.org; Email: contact@knime.org
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, Version 3, as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, see <http://www.gnu.org/licenses>.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  KNIME interoperates with ECLIPSE solely via ECLIPSE's plug-in APIs.
 *  Hence, KNIME and ECLIPSE are both independent programs and are not
 *  derived from each other. Should, however, the interpretation of the
 *  GNU GPL Version 3 ("License") under any applicable laws result in
 *  KNIME and ECLIPSE being a combined program, KNIME GMBH herewith grants
 *  you the additional permission to use and propagate KNIME together with
 *  ECLIPSE with only the license terms in place for ECLIPSE applying to
 *  ECLIPSE and the GNU GPL Version 3 applying for KNIME, provided the
 *  license terms of ECLIPSE themselves allow for the respective use and
 *  propagation of ECLIPSE together with KNIME.
 *
 *  Additional permission relating to nodes for KNIME that extend the Node
 *  Extension (and in particular that are based on subclasses of NodeModel,
 *  NodeDialog, and NodeView) and that only interoperate with KNIME through
 *  standard APIs ("Nodes"):
 *  Nodes are deemed to be separate and independent programs and to not be
 *  covered works.  Notwithstanding anything to the contrary in the
 *  License, the License does not apply to Nodes, you are not required to
 *  license Nodes under the License, and you are granted a license to
 *  prepare and propagate Nodes, in each case even if such Nodes are
 *  propagated with or for interoperation with KNIME.  The owner of a Node
 *  may freely choose the license terms applicable to such Node, including
 *  when such Node is propagated with or for interoperation with KNIME.
 * ---------------------------------------------------------------------
 *
 * Created on 16.08.2013 by Kilian Thiel
 */
package org.knime.example.tagset;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.knime.ext.textprocessing.data.Tag;
import org.knime.ext.textprocessing.data.TagBuilder;

/**
 * The SentimentTagSet provides an example sentiment tag set with positive, negative and neutral tags. 
 * The type of the tag set is "SENTIMENT".
 * @author Kilian Thiel, KNIME.com, Zurich, Switzerland
 *
 */
public class SentimentTagSet implements TagBuilder {
	
    /** Tag type. */
    public static final String TAG_TYPE = "SENTIMENT";
    
    /** Default tag value. */
    public static final String DEFAULT_TAG = SentimentTag.NEUTRAL.toString();

    /** Map storing all tags and their related values. */
    private Map<String, Tag> m_tagMap;
    
    /**
     * Constructor has to be public!
     */
    public SentimentTagSet() { 
    	m_tagMap = new HashMap<String, Tag>();
    	// fill maps with all tag values and their related tags.
    	for (SentimentTag tagValue : SentimentTag.values()) {
    		m_tagMap.put(tagValue.toString(), new Tag(tagValue.toString(), TAG_TYPE));
    	}
    }
    
	/* Returns the type of tag.
	 * @see org.knime.ext.textprocessing.data.TagBuilder#getType()
	 */
	@Override
	public String getType() {
		return SentimentTagSet.TAG_TYPE;
	}    
    

    /* Returns the tags as list of strings.
     * @see org.knime.ext.textprocessing.data.TagBuilder#asStringList()
     */
    public List<String> asStringList() {
        List<String> list = new ArrayList<String>(m_tagMap.size());
        list.addAll(m_tagMap.keySet());
        return list;
    }	
	
	/* Creates the corresponding Tag instance of the given string.
	 * @see org.knime.ext.textprocessing.data.TagBuilder#buildTag(java.lang.String)
	 */
	@Override
	public Tag buildTag(final String value) {
        Tag tag = m_tagMap.get(value);
        if (tag == null) {
        	tag = m_tagMap.get(DEFAULT_TAG);
        }
        return tag;
	}   
    
	/* Returns a set of all tags of the tag set.
	 * @see org.knime.ext.textprocessing.data.TagBuilder#getTags()
	 */
	@Override
	public Set<Tag> getTags() {
        Set<Tag> tagSet = new HashSet<Tag>(m_tagMap.size());
        tagSet.addAll(m_tagMap.values());
        return tagSet;
	}
}
